@@ -1,7 +1,11 @@
 package App::PPH21Utils;
 
-our $DATE = '2017-05-24'; # DATE
-our $VERSION = '0.03'; # VERSION
+use strict;
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-03-30'; # DATE
+our $DIST = 'App-PPH21Utils'; # DIST
+our $VERSION = '0.040'; # VERSION
 
 1;
 # ABSTRACT: CLI utilities related to Indonesian income tax article 21 ("PPH21")
@@ -18,7 +22,7 @@ App::PPH21Utils - CLI utilities related to Indonesian income tax article 21 ("PP
 
 =head1 VERSION
 
-This document describes version 0.03 of App::PPH21Utils (from Perl distribution App-PPH21Utils), released on 2017-05-24.
+This document describes version 0.040 of App::PPH21Utils (from Perl distribution App-PPH21Utils), released on 2023-03-30.
 
 =head1 DESCRIPTION
 
@@ -44,14 +48,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-PPH21U
 
 Source repository is at L<https://github.com/perlancar/perl-App-PPH21Utils>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-PPH21Utils>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Business::Tax::ID::PPH21>
@@ -60,11 +56,37 @@ L<Business::Tax::ID::PPH21>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2023, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-PPH21Utils>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
